@@ -24,6 +24,8 @@ import octobot_commons.logging as commons_logging
 import octobot_commons.configuration as commons_configuration
 import octobot_commons.databases as commons_databases
 import octobot_commons.constants as commons_constants
+import octobot_commons.enums as commons_enums
+import octobot_commons.list_util as list_util
 import octobot_commons.asyncio_tools as asyncio_tools
 
 import octobot_backtesting.api as backtesting_api
@@ -48,21 +50,27 @@ import octobot.databases_util as databases_util
 
 
 class OctoBotBacktesting:
-
-    def __init__(self, backtesting_config,
-                 tentacles_setup_config,
-                 symbols_to_create_exchange_classes,
-                 backtesting_files,
-                 run_on_common_part_only,
-                 start_timestamp=None,
-                 end_timestamp=None,
-                 enable_logs=True,
-                 enable_storage=True,
-                 run_on_all_available_time_frames=False,
-                 backtesting_data=None):
+    def __init__(
+        self,
+        backtesting_config,
+        tentacles_setup_config,
+        symbols_to_create_exchange_classes,
+        backtesting_files,
+        run_on_common_part_only,
+        start_timestamp=None,
+        end_timestamp=None,
+        enable_logs=True,
+        enable_storage=True,
+        run_on_all_available_time_frames=False,
+        backtesting_data=None,
+        name=None,
+        config_by_tentacle=None,
+        services_config=None,
+    ):
         self.logger = commons_logging.get_logger(self.__class__.__name__)
         self.backtesting_config = backtesting_config
         self.tentacles_setup_config = tentacles_setup_config
+        self.config_by_tentacle: dict = config_by_tentacle
         self.bot_id = str(uuid.uuid4())
         self.matrix_id = ""
         self.exchange_manager_ids = []
@@ -71,6 +79,7 @@ class OctoBotBacktesting:
         self.service_feeds = []
         self.backtesting_files = backtesting_files
         self.backtesting_data = backtesting_data
+        self.name = name
         if self.backtesting_data is not None:
             self.backtesting_files = [
                 backtesting_file
@@ -87,6 +96,8 @@ class OctoBotBacktesting:
         self.enable_storage = enable_storage
         self.run_on_all_available_time_frames = run_on_all_available_time_frames
         self._has_started = False
+        self.has_fetched_data = False
+        self.services_config = services_config
 
     async def initialize_and_run(self):
         if not constants.ENABLE_BACKTESTING:
@@ -106,9 +117,13 @@ class OctoBotBacktesting:
         await self._init_backtesting()
         await self._init_evaluators()
         await self._init_service_feeds()
+        min_timestamp, max_timestamp = await self._configure_backtesting_time_window()
         await self._init_exchanges()
         self._ensure_limits()
         await self._create_evaluators()
+        await self._fetch_backtesting_extra_data_if_any(
+            min_timestamp, max_timestamp
+        )
         await self._create_service_feeds()
         await backtesting_api.start_backtesting(self.backtesting)
         if logger.BOT_CHANNEL_LOGGER is not None and self.enable_logs:
@@ -127,7 +142,7 @@ class OctoBotBacktesting:
             exchange: [str(s) for s in symbols]
             for exchange, symbols in self.symbols_to_create_exchange_classes.items()
         }
-        self.logger.info(f"Stopping for {self.backtesting_files} with {symbols_by_exchange}")
+        self.logger.debug(f"Stopping for {self.backtesting_files} with {symbols_by_exchange}")
         exchange_managers = []
         try:
             if self.backtesting is None:
@@ -191,6 +206,7 @@ class OctoBotBacktesting:
             self.backtesting = None
 
     def memory_leak_checkup(self, to_check_elements):
+        gc.collect()
         self.logger.debug(f"Memory leak checking {[e.__class__.__name__ for e in to_check_elements]}")
         memory_leak_errors = []
         for i in range(len(to_check_elements)):
@@ -223,6 +239,8 @@ class OctoBotBacktesting:
             exchanges.ExchangeSimulator: exchanges_count,
             exchange_data.OHLCVUpdaterSimulator: exchanges_count
         }
+        # trigger garbage collector to get a fresh memory picture
+        gc.collect()
         for obj in gc.get_objects():
             if isinstance(obj, to_watch_objects):
                 if isinstance(obj, exchanges.ExchangeManager) and not obj.is_initialized:
@@ -260,6 +278,7 @@ class OctoBotBacktesting:
             self.start_time,
             user_inputs,
             commons_databases.RunDatabasesProvider.instance().get_run_databases_identifier(self.bot_id),
+            self.name
         )
         self.logger.info(f"Backtesting metadata:\n{json.dumps(metadata, indent=4)}")
 
@@ -267,7 +286,14 @@ class OctoBotBacktesting:
         self.matrix_id = evaluator_api.create_matrix()
 
     async def _init_evaluators(self):
-        await evaluator_api.initialize_evaluators(self.backtesting_config, self.tentacles_setup_config)
+        await evaluator_api.initialize_evaluators(
+            self.backtesting_config, self.tentacles_setup_config, config_by_evaluator=self.config_by_tentacle
+        )
+        if (not self.backtesting_config[commons_constants.CONFIG_TIME_FRAME]) and \
+           evaluator_constants.CONFIG_FORCED_TIME_FRAME in self.backtesting_config:
+            self.backtesting_config[commons_constants.CONFIG_TIME_FRAME] = self.backtesting_config[
+                evaluator_constants.CONFIG_FORCED_TIME_FRAME
+            ]
         await evaluator_api.create_evaluator_channels(self.matrix_id, is_backtesting=True)
 
     async def _init_service_feeds(self):
@@ -300,7 +326,9 @@ class OctoBotBacktesting:
                 symbols_by_crypto_currencies=exchange_configuration.symbols_by_crypto_currencies,
                 symbols=exchange_configuration.symbols,
                 time_frames=exchange_configuration.available_required_time_frames,
-                real_time_time_frames=exchange_configuration.real_time_time_frames)
+                real_time_time_frames=exchange_configuration.real_time_time_frames,
+                config_by_evaluator=self.config_by_tentacle,
+            )
 
     async def _create_service_feeds(self):
         for feed in self.service_feeds:
@@ -317,7 +345,8 @@ class OctoBotBacktesting:
             matrix_id=self.matrix_id,
             data_files=self.backtesting_files,
             importers_by_data_file=self.backtesting_data.importers_by_data_file if self.backtesting_data else None,
-            backtest_data=self.backtesting_data
+            backtest_data=self.backtesting_data,
+            bot_id=self.bot_id,
         )
         if self.run_on_all_available_time_frames:
             self.backtesting_config[evaluator_constants.CONFIG_FORCED_TIME_FRAME] = [
@@ -325,22 +354,69 @@ class OctoBotBacktesting:
                 for tf in self.backtesting.importers[0].time_frames
             ]
 
-    async def _init_exchanges(self):
+    async def _configure_backtesting_time_window(self):
         # modify_backtesting_channels before creating exchanges as they require the current backtesting time to
         # initialize
-        await backtesting_api.adapt_backtesting_channels(self.backtesting,
-                                                         self.backtesting_config,
-                                                         importers.ExchangeDataImporter,
-                                                         run_on_common_part_only=self.run_on_common_part_only,
-                                                         start_timestamp=self.start_timestamp,
-                                                         end_timestamp=self.end_timestamp)
+        min_timestamp, max_timestamp = await backtesting_api.adapt_backtesting_channels(
+            self.backtesting,
+            self.backtesting_config,
+            importers.ExchangeDataImporter,
+            run_on_common_part_only=self.run_on_common_part_only,
+            start_timestamp=self.start_timestamp,
+            end_timestamp=self.end_timestamp
+        )
+        return min_timestamp, max_timestamp
 
+    async def _fetch_backtesting_extra_data_if_any(
+        self, min_timestamp: float, max_timestamp: float
+    ):
+        if not self.evaluators:
+            return
+        handled_classes = set()
+        coros = []
+        for evaluator in list_util.flatten_list(self.evaluators):
+            if evaluator and evaluator.get_name() not in handled_classes:
+                if evaluator.get_signals_history_type() == commons_enums.SignalHistoryTypes.GPT:
+                    coros.append(self._fetch_gpt_history(evaluator, min_timestamp, max_timestamp))
+                handled_classes.add(evaluator.get_name())
+        if coros:
+            self.has_fetched_data = True
+            await asyncio.gather(*coros)
+
+    async def _fetch_gpt_history(self, evaluator, min_timestamp: float, max_timestamp: float):
+        # prevent circular import
+        import tentacles.Services.Services_bases.gpt_service as gpt_service
+        service = await service_api.get_service(gpt_service.GPTService, True, self.services_config)
+        version = evaluator.get_version()
+        for exchange_id in self.exchange_manager_ids:
+            exchange_configuration = trading_api.get_exchange_configuration_from_exchange_id(exchange_id)
+            exchange_name = trading_api.get_exchange_name(
+                trading_api.get_exchange_manager_from_exchange_id(exchange_id)
+            )
+            await service.fetch_gpt_history(
+                exchange_name,
+                [str(symbol) for symbol in self.symbols_to_create_exchange_classes.get(exchange_name, [])],
+                exchange_configuration.available_required_time_frames,
+                version,
+                min_timestamp,
+                max_timestamp
+            )
+
+    async def clear_fetched_data(self):
+        if self.has_fetched_data:
+            # prevent circular import
+            import tentacles.Services.Services_bases.gpt_service as gpt_service
+            (await service_api.get_service(gpt_service.GPTService, True, self.services_config)).clear_signal_history()
+
+    async def _init_exchanges(self):
         for exchange_class_string in self.symbols_to_create_exchange_classes.keys():
             is_future = self.exchange_type_by_exchange[exchange_class_string] == \
                         commons_constants.CONFIG_EXCHANGE_FUTURE
             exchange_builder = trading_api.create_exchange_builder(self.backtesting_config, exchange_class_string) \
                 .has_matrix(self.matrix_id) \
                 .use_tentacles_setup_config(self.tentacles_setup_config) \
+                .use_trading_config_by_trading_mode(self.config_by_tentacle) \
+                .use_cached_markets(self.backtesting_data.use_cached_markets if self.backtesting_data else False) \
                 .set_bot_id(self.bot_id) \
                 .is_simulated() \
                 .is_rest_only() \
