@@ -22,26 +22,26 @@ from octobot.community.errors import (
     BotNotFoundError,
     NoBotDeviceError,
 )
-from octobot.community import identifiers_provider
-from octobot.community.identifiers_provider import (
-    IdentifiersProvider,
-)
-from octobot.community import community_user_account
-from octobot.community.community_user_account import (
+from octobot.community import models
+from octobot.community.models import (
     CommunityUserAccount,
-)
-from octobot.community import community_fields
-from octobot.community.community_fields import (
     CommunityFields,
+    CommunityTentaclesPackage,
+    CommunitySupports,
+    CommunityDonation,
+    StartupInfo,
+    StrategyData,
+)
+from octobot.community.supabase_backend import (
+    SyncConfigurationStorage,
+    ASyncConfigurationStorage,
+    AuthenticatedAsyncSupabaseClient,
+    CommunitySupabaseClient,
 )
 
 from octobot.community import community_analysis
 from octobot.community import community_manager
 from octobot.community import authentication
-from octobot.community import community_tentacles_package
-from octobot.community import community_supports
-from octobot.community import community_donation
-from octobot.community import startup_info
 from octobot.community import graphql_requests
 from octobot.community import feeds
 from octobot.community import errors_upload
@@ -57,18 +57,6 @@ from octobot.community.community_manager import (
 from octobot.community.authentication import (
     CommunityAuthentication,
 )
-from octobot.community.community_tentacles_package import (
-    CommunityTentaclesPackage
-)
-from octobot.community.community_supports import (
-    CommunitySupports
-)
-from octobot.community.community_donation import (
-    CommunityDonation
-)
-from octobot.community.startup_info import (
-    StartupInfo
-)
 from octobot.community.graphql_requests import (
     select_startup_info_query,
     select_bot_query,
@@ -89,9 +77,11 @@ from octobot.community.feeds import (
     community_feed_factory,
 )
 from octobot.community.errors_upload import (
-    register_error_uploader,
-    Error,
-    ErrorsUploader,
+    init_sentry_tracker,
+    flush_tracker,
+)
+from octobot.community.identifiers_provider import (
+    IdentifiersProvider,
 )
 
 __all__ = [
@@ -111,10 +101,14 @@ __all__ = [
     "CommunityTentaclesPackage",
     "CommunitySupports",
     "CommunityDonation",
-    "register_error_uploader",
-    "Error",
-    "ErrorsUploader",
+    "init_sentry_tracker",
+    "flush_tracker",
     "StartupInfo",
+    "StrategyData",
+    "SyncConfigurationStorage",
+    "ASyncConfigurationStorage",
+    "AuthenticatedAsyncSupabaseClient",
+    "CommunitySupabaseClient",
     "select_startup_info_query",
     "select_bot_query",
     "select_bots_query",
