@@ -32,5 +32,29 @@ class BotNotFoundError(BotError):
     pass
 
 
+class BotDeploymentURLNotFoundError(BotError):
+    pass
+
+
+class MissingBotConfigError(BotError):
+    pass
+
+
+class InvalidBotConfigError(BotError):
+    pass
+
+
+class MissingProductConfigError(BotError):
+    pass
+
+
+class EmailValidationRequiredError(commons_authentication.AuthenticationError):
+    pass
+
+
 class NoBotDeviceError(BotError):
     pass
+
+
+class ExtensionRequiredError(Exception):
+    pass
