@@ -32,6 +32,9 @@ class AbstractFeed:
         self.is_signal_receiver = False
         self.is_signal_emitter = False
 
+    def has_registered_feed(self) -> bool:
+        return bool(self.feed_callbacks)
+
     async def start(self):
         raise NotImplementedError("start is not implemented")
 
@@ -48,7 +51,13 @@ class AbstractFeed:
         return True
 
     def is_connected_to_remote_feed(self):
-        raise NotImplementedError("is_connected_to_remote_feed is not implemented")
+        return False
 
     def update_last_message_time(self):
         self.last_message_time = time.time()
+
+    def is_up_to_date_with_account(self, user_account):
+        return True
+
+    def is_connected(self):
+        return False
