@@ -154,8 +154,8 @@ def get_default_tentacles_url(version=None):
             if constants.TENTACLES_REQUIRED_VERSION else constants.LONG_VERSION
     return os.getenv(
         constants.ENV_TENTACLES_URL,
+        f"https://{tentacles_repository}."
         f"{constants.OCTOBOT_ONLINE}/"
-        f"{tentacles_repository}/"
         f"{os.getenv(constants.ENV_TENTACLES_PACKAGES_SOURCE, constants.OFFICIALS)}/"
         f"{os.getenv(constants.ENV_TENTACLES_PACKAGES_TYPE, constants.TENTACLE_PACKAGES)}/"
         f"{os.getenv(constants.ENV_TENTACLE_CATEGORY, constants.TENTACLE_CATEGORY)}/"
@@ -165,17 +165,6 @@ def get_default_tentacles_url(version=None):
     )
 
 
-def get_default_compiled_tentacles_url():
-    return os.getenv(
-        constants.ENV_COMPILED_TENTACLES_URL,
-        f"{constants.OCTOBOT_ONLINE}/{constants.TENTACLES_REPOSITORY}/"
-        f"{os.getenv(constants.ENV_TENTACLES_PACKAGES_SOURCE, constants.OFFICIALS)}/"
-        f"{os.getenv(constants.ENV_COMPILED_TENTACLES_PACKAGES_TYPE, constants.TENTACLE_PACKAGES)}/"
-        f"{os.getenv(constants.ENV_COMPILED_TENTACLES_CATEGORY, constants.COMPILED_TENTACLE_CATEGORY)}/"
-        f"{os.getenv(constants.ENV_COMPILED_TENTACLES_SUBCATEGORY, '')}"
-    )
-
-
 def get_user_local_config_file():
     try:
         import octobot_commons.constants as commons_constants
