@@ -17,13 +17,17 @@ import math
 import numpy
 
 import octobot_commons.enums as common_enums
+import octobot_commons.logging as commons_logging
+import octobot_commons.constants as commons_constants
 import octobot_commons.databases as commons_databases
 import octobot_commons.configuration as commons_configuration
+import octobot_commons.time_frame_manager as time_frame_manager
 
 import octobot_backtesting.api as backtesting_api
 
 import octobot_trading.api as trading_api
 import octobot_trading.enums as trading_enums
+import octobot.backtesting as backtesting
 
 
 async def clear_run_metadata(bot_id):
@@ -35,7 +39,7 @@ async def store_run_metadata(bot_id, exchange_managers, start_time, user_inputs=
     run_db = commons_databases.RunDatabasesProvider.instance().get_run_db(bot_id)
     user_inputs = user_inputs or await commons_configuration.get_user_inputs(run_db)
     run_dbs_identifier = commons_databases.RunDatabasesProvider.instance().get_run_databases_identifier(bot_id)
-    metadata = await _get_trading_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier, False)
+    metadata = await _get_trading_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier, False, None)
     await run_db.log(
         common_enums.DBTables.METADATA.value,
         metadata
@@ -45,8 +49,8 @@ async def store_run_metadata(bot_id, exchange_managers, start_time, user_inputs=
     return metadata
 
 
-async def store_backtesting_run_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier) -> dict:
-    run_metadata = await _get_trading_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier, True)
+async def store_backtesting_run_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier, name) -> dict:
+    run_metadata = await _get_trading_metadata(exchange_managers, start_time, user_inputs, run_dbs_identifier, True, name)
     # use local database as a lock is required
     async with commons_databases.DBWriter.database(
             run_dbs_identifier.get_backtesting_metadata_identifier(),
@@ -55,9 +59,17 @@ async def store_backtesting_run_metadata(exchange_managers, start_time, user_inp
     return run_metadata
 
 
-async def _get_trading_metadata(exchange_managers, run_start_time, user_inputs, run_dbs_identifier, is_backtesting) \
+async def _get_trading_metadata(exchange_managers, run_start_time, user_inputs, run_dbs_identifier, is_backtesting, name) \
         -> dict:
-    trading_mode = trading_api.get_trading_modes(exchange_managers[0])[0]
+    try:
+        trading_mode = trading_api.get_trading_modes(exchange_managers[0])[0]
+    except IndexError:
+        import tentacles.Trading.Mode
+        commons_logging.get_logger(__name__).debug(
+            f"Using {tentacles.Trading.Mode.BlankTradingMode.get_name()} as a fallback for metadata as "
+            f"no trading mode is selected"
+        )
+        trading_mode = tentacles.Trading.Mode.BlankTradingMode(exchange_managers[0].config, exchange_managers[0])
     multi_exchanges_data = await _get_multi_exchange_data(exchange_managers, is_backtesting)
     single_exchange_data = await _get_single_exchange_data(
         exchange_managers[0],
@@ -65,7 +77,8 @@ async def _get_trading_metadata(exchange_managers, run_start_time, user_inputs,
         run_start_time,
         user_inputs,
         run_dbs_identifier,
-        is_backtesting
+        is_backtesting,
+        name
     )
     return {
         **single_exchange_data,
@@ -98,24 +111,12 @@ async def _get_multi_exchange_data(exchange_managers, is_backtesting):
         float(trading_api.get_profitability_stats(exchange_manager)[1])
         for exchange_manager in exchange_managers
     ))
+    markets_profitability = _get_markets_profitability(exchange_managers, time_frames) if is_backtesting else {}
     exchange_names = [
         trading_api.get_exchange_name(exchange_manager)
         for exchange_manager in exchange_managers
     ]
-    future_contracts_by_exchange = {
-        trading_api.get_exchange_name(exchange_manager): {
-            symbol: {
-                "contract_type": contract.contract_type.value,
-                "position_mode": contract.position_mode.value,
-                "margin_type": contract.margin_type.value
-            }
-            for symbol, contract in trading_api.get_pair_contracts(exchange_manager).items()
-            if symbol in trading_api.get_trading_pairs(exchange_manager)
-            and trading_api.is_handled_contract(contract)
-        }
-        for exchange_manager in exchange_managers
-        if exchange_manager.is_future and hasattr(exchange_manager.exchange, "pair_contracts")
-    }
+    future_contracts_by_exchange = _get_future_contracts_by_exchange(exchange_managers)
     trades = [
         trade
         for exchange_manager in exchange_managers
@@ -135,23 +136,8 @@ async def _get_multi_exchange_data(exchange_managers, is_backtesting):
         float(trading_api.get_draw_down(exchange_manager))
         for exchange_manager in exchange_managers
     )), 3)
-    try:
-        r_sq_end_balance = numpy.average([
-            await trading_api.get_coefficient_of_determination(
-                exchange_manager,
-                use_high_instead_of_end_balance=False
-            )
-            for exchange_manager in exchange_managers
-        ])
-    except KeyError:
-        r_sq_end_balance = None
-    try:
-        r_sq_max_balance = numpy.average([
-            await trading_api.get_coefficient_of_determination(exchange_manager)
-            for exchange_manager in exchange_managers
-        ])
-    except KeyError:
-        r_sq_max_balance = None
+    r_sq_end_balance = await _get_coefficient_of_determination(exchange_managers, False)
+    r_sq_max_balance = await _get_coefficient_of_determination(exchange_managers, True)
     duration = round(max(
         backtesting_api.get_backtesting_duration(exchange_manager.exchange.backtesting)
         for exchange_manager in exchange_managers
@@ -168,32 +154,7 @@ async def _get_multi_exchange_data(exchange_managers, is_backtesting):
     else:
         start_time = exchange_managers[0].exchange.get_exchange_current_time()
         end_time = -1
-    origin_portfolio = {}
-    end_portfolio = {}
-    for exchange_manager in exchange_managers:
-        try:
-            exchange_origin_portfolio = trading_api.get_origin_portfolio(exchange_manager, as_decimal=False)
-        except AttributeError:
-            # no initialized portfolio on this exchange
-            continue
-        exchange_end_portfolio = trading_api.get_portfolio(exchange_manager, as_decimal=False)
-        for portfolio in (exchange_origin_portfolio, exchange_end_portfolio):
-            for values in portfolio.values():
-                values.pop("available", None)
-        if exchange_manager.is_future:
-            for position in trading_api.get_positions(exchange_manager):
-                exchange_end_portfolio[position.get_currency()]["position"] = float(position.quantity)
-        for exchange_portfolio, portfolio in zip((exchange_origin_portfolio, exchange_end_portfolio),
-                                                 (origin_portfolio, end_portfolio)):
-            for currency, value_dict in exchange_portfolio.items():
-                try:
-                    pf_value = portfolio[currency]
-                except KeyError:
-                    pf_value = {}
-                    portfolio[currency] = pf_value
-                for key, value in value_dict.items():
-                    pf_value[key] = pf_value.get(key, 0) + value
-
+    origin_portfolio, end_portfolio = _get_portfolio(exchange_managers)
     backtesting_only_metadata = {
         common_enums.BacktestingMetadata.DURATION.value: duration,
         common_enums.BacktestingMetadata.BACKTESTING_FILES.value: data_files,
@@ -203,6 +164,8 @@ async def _get_multi_exchange_data(exchange_managers, is_backtesting):
         **{
             common_enums.BacktestingMetadata.GAINS.value: round(float(profitability), 8),
             common_enums.BacktestingMetadata.PERCENT_GAINS.value: round(float(profitability_percent), 3),
+            common_enums.BacktestingMetadata.MARKETS_PROFITABILITY.value:
+                {c: f"{round(float(v) * 100, 2)}%" for c, v in markets_profitability.items()},
             common_enums.BacktestingMetadata.END_PORTFOLIO.value: str(end_portfolio),
             common_enums.BacktestingMetadata.START_PORTFOLIO.value: str(origin_portfolio),
             common_enums.BacktestingMetadata.WIN_RATE.value: win_rate,
@@ -223,8 +186,90 @@ async def _get_multi_exchange_data(exchange_managers, is_backtesting):
     }
 
 
+async def _get_coefficient_of_determination(exchange_managers, use_high_instead_of_end_balance):
+    try:
+        return numpy.average([
+            await trading_api.get_coefficient_of_determination(
+                exchange_manager,
+                use_high_instead_of_end_balance=use_high_instead_of_end_balance
+            )
+            for exchange_manager in exchange_managers
+        ])
+    except KeyError:
+        return None
+
+
+def _get_markets_profitability(exchange_managers, time_frames):
+    markets_profitability = {}
+    min_tf = time_frame_manager.find_min_time_frame(time_frames)
+    for exchange_manager in exchange_managers:
+        for symbol in trading_api.get_trading_pairs(exchange_manager):
+            if symbol is markets_profitability:
+                continue
+            try:
+                markets_profitability[symbol] = \
+                    backtesting.IndependentBacktesting.get_market_delta(symbol, exchange_manager, min_tf)
+            except Exception:
+                pass
+    return markets_profitability
+
+
+def _get_portfolio(exchange_managers):
+    origin_portfolio = {}
+    end_portfolio = {}
+    for exchange_manager in exchange_managers:
+        try:
+            exchange_origin_portfolio = trading_api.get_origin_portfolio(exchange_manager, as_decimal=False)
+        except AttributeError:
+            # no initialized portfolio on this exchange
+            continue
+        exchange_end_portfolio = trading_api.get_portfolio(exchange_manager, as_decimal=False)
+        for portfolio in (exchange_origin_portfolio, exchange_end_portfolio):
+            for values in portfolio.values():
+                values.pop("available", None)
+        if exchange_manager.is_future:
+            for position in trading_api.get_positions(exchange_manager):
+                try:
+                    exchange_end_portfolio[position.get_currency()]["position"] = float(position.quantity)
+                except KeyError:
+                    exchange_end_portfolio[position.get_currency()] = {
+                        commons_constants.PORTFOLIO_AVAILABLE: 0,
+                        commons_constants.PORTFOLIO_TOTAL: 0,
+                        "position": float(position.quantity),
+                    }
+
+        for exchange_portfolio, portfolio in zip((exchange_origin_portfolio, exchange_end_portfolio),
+                                                 (origin_portfolio, end_portfolio)):
+            for currency, value_dict in exchange_portfolio.items():
+                try:
+                    pf_value = portfolio[currency]
+                except KeyError:
+                    pf_value = {}
+                    portfolio[currency] = pf_value
+                for key, value in value_dict.items():
+                    pf_value[key] = pf_value.get(key, 0) + value
+    return origin_portfolio, end_portfolio
+
+
+def _get_future_contracts_by_exchange(exchange_managers):
+    return {
+        trading_api.get_exchange_name(exchange_manager): {
+            symbol: {
+                "contract_type": contract.contract_type.value,
+                "position_mode": contract.position_mode.value,
+                "margin_type": contract.margin_type.value
+            }
+            for symbol, contract in trading_api.get_pair_contracts(exchange_manager).items()
+            if symbol in trading_api.get_trading_pairs(exchange_manager)
+            and trading_api.is_handled_contract(contract)
+        }
+        for exchange_manager in exchange_managers
+        if exchange_manager.is_future and hasattr(exchange_manager.exchange, "pair_contracts")
+    }
+
+
 async def _get_single_exchange_data(exchange_manager, trading_mode, run_start_time, user_inputs, run_dbs_identifier,
-                                    is_backtesting):
+                                    is_backtesting, name):
     exchange_type = trading_enums.ExchangeTypes.FUTURE.value if exchange_manager.is_future \
         else trading_enums.ExchangeTypes.SPOT.value
     if user_inputs is None:
@@ -251,7 +296,7 @@ async def _get_single_exchange_data(exchange_manager, trading_mode, run_start_ti
         **backtesting_only_metadata,
         **{
             common_enums.BacktestingMetadata.TIMESTAMP.value: run_start_time,
-            common_enums.BacktestingMetadata.NAME.value: trading_mode.get_name(),
+            common_enums.BacktestingMetadata.NAME.value: name or trading_mode.get_name(),
             common_enums.BacktestingMetadata.LEVERAGE.value: leverage,
             common_enums.DBRows.TRADING_TYPE.value: exchange_type,
             common_enums.DBRows.REFERENCE_MARKET.value: trading_api.get_reference_market(exchange_manager.config),
