@@ -19,6 +19,7 @@ import octobot.constants as constants
 import octobot.configuration_manager as configuration_manager
 import octobot.commands as commands
 import octobot_commons.logging as logging
+import octobot_commons.authentication as authentication
 
 
 class Updater:
@@ -44,8 +45,14 @@ class Updater:
         raise NotImplementedError("update_impl is not implemented")
 
     async def update_tentacles(self):
+        bot_version = await self.get_latest_version()
+        authenticator = authentication.Authenticator.instance()
+        additional_tentacles_package_urls = authenticator.get_saved_package_urls()
         await commands.install_all_tentacles(
-            tentacles_url=configuration_manager.get_default_tentacles_url(version=await self.get_latest_version()))
+            tentacles_url=configuration_manager.get_default_tentacles_url(version=bot_version),
+            additional_tentacles_package_urls=additional_tentacles_package_urls,
+            bot_version=bot_version
+        )
 
     async def post_update(self):
         await self.update_tentacles()
